#ifndef NVIM_API_BUFFER_H
#define NVIM_API_BUFFER_H

#include <lauxlib.h>

#include "nvim/api/private/defs.h"
#include "nvim/buffer_defs.h"

#ifdef INCLUDE_GENERATED_DECLARATIONS
# include "api/buffer.h.generated.h"
#endif
#endif  // NVIM_API_BUFFER_H
